Documentation
¶
Overview ¶
Package proxy provides wrappers around various proxy server implementations.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Protocol ¶
type Protocol uint8
Protocol is a wrapper around uint8.
func ParseProto ¶
ParseProto takes a string as input and returns its Protocol value, is one is recognised. Otherwise it returns an error.
type Proxy ¶
type Proxy interface {
// Protocol is the string representation of the protocol
// beign used.
Protocol() string
// ListenAndServe reveleas the proxy to the network.
ListenAndServe(ctx context.Context, port int) error
// DialWith makes the proxy dial new connections with the
// assigned dialer.
DialWith(d dialer.Dialer)
}
Proxy explains how a proxy should behave.
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
proxy
command
|
|
|
Package dialer provides utility functions related to dialers.
|
Package dialer provides utility functions related to dialers. |
|
Package http provides a http proxy implementation.
|
Package http provides a http proxy implementation. |
|
Package socks5 provides a SOCKS5 server implementation.
|
Package socks5 provides a SOCKS5 server implementation. |
|
Package transmit provides utility functions to proxy data through network connections, with control over timeouts.
|
Package transmit provides utility functions to proxy data through network connections, with control over timeouts. |
Click to show internal directories.
Click to hide internal directories.